@@ -37,12 +37,51 @@
 */
 
 
+#define OCISessionRelease_log_stat(svchp, errhp,stat)\
+	stat =OCISessionRelease(svchp, errhp, NULL, (ub4)0, OCI_DEFAULT);\
+	(DBD_OCI_TRACEON) \
+					? PerlIO_printf(DBD_OCI_TRACEFP,\
+						 "%sOCISessionRelease(svchp=%p)=%s\n",\
+						 OciTp, svchp,oci_status_name(stat)),stat \
+	: stat
+#define OCISessionPoolDestroy_log_stat(ph, errhp,stat )\
+	stat =OCISessionPoolDestroy(ph, errhp,OCI_DEFAULT);\
+	(DBD_OCI_TRACEON) \
+				? PerlIO_printf(DBD_OCI_TRACEFP,\
+					 "%sOCISessionPoolDestroy(ph=%p)=%s\n",\
+					 OciTp, ph,oci_status_name(stat)),stat \
+	: stat
+#define OCISessionGet_log_stat(envhp, errhp, sh, ah,pn,pnl,stat)\
+	stat =OCISessionGet(envhp, errhp, sh, ah,pn,pnl,NULL,0, NULL, NULL, NULL, OCI_SESSGET_SPOOL);\
+	(DBD_OCI_TRACEON) \
+				? PerlIO_printf(DBD_OCI_TRACEFP,\
+					 "%sOCISessionGet(envhp=%p,sh=%p,ah=%p,pn=%p,pnl=%d)=%s\n",\
+					 OciTp, envhp,sh,ah,pn,pnl,oci_status_name(stat)),stat \
+	: stat
+
+#define OCISessionPoolCreate_log_stat(envhp,errhp,ph,pn,pnl,dbn,dbl,sn,sm,si,un,unl,pw,pwl,stat)\
+    stat =OCISessionPoolCreate(envhp,errhp,ph,pn,pnl,dbn,dbl,sn,sm,si,un,unl,pw,pwl,OCI_DEFAULT);\
+    (DBD_OCI_TRACEON) \
+				? PerlIO_printf(DBD_OCI_TRACEFP,\
+					 "%sOCISessionPoolCreate(envhp=%p,ph=%p,pn=%p,pnl=%p,min=%d,max=%d,incr=%d, un=%s,unl=%d,pw=%s,pwl=%d)=%s\n",\
+					 OciTp, envhp,ph,pn,pnl,sn,sm,si,un,unl,pw,pwl,oci_status_name(stat)),stat \
+	: stat
+
+#if defined(ORA_OCI_102)
+#define OCIPing_log_stat(sc,errhp,stat)\
+	stat =OCIPing(sc,errhp,OCI_DEFAULT);\
+	(DBD_OCI_TRACEON) \
+			? PerlIO_printf(DBD_OCI_TRACEFP,\
+				 "%sOCIPing(%p)=%s\n",\
+				 OciTp, sc,oci_status_name(stat)),stat \
+	: stat
+#endif
 
 #define OCIServerVersion_log_stat(sc,errhp,b,bl,ht,stat)\
 	stat =OCIServerVersion(sc,errhp,b,bl,ht);\
 	(DBD_OCI_TRACEON) \
 			? PerlIO_printf(DBD_OCI_TRACEFP,\
-				 "%sCIServerVersion_log_stat(%p,%s)=%s\n",\
+				 "%sOCIServerVersion_log_stat(%p,%s)=%s\n",\
 				 OciTp, sc,b,oci_status_name(stat)),stat \
 	: stat
 
@@ -80,12 +119,12 @@
 				 OciTp,	(void*)svchp,(void*)envhp, src_type, src_ptr,oci_status_name(stat)),stat \
 	: stat
 
-#define OCILobLocatorIsInit_log_stat(envhp,errhp,loc,is_init,stat)\
-	stat =OCILobLocatorIsInit (envhp,errhp,loc,is_init );\
+#define OCILobLocatorIsInit_log_stat(envhp,errhp,loc,is_initp,stat)\
+	stat =OCILobLocatorIsInit (envhp,errhp,loc,is_initp );\
 	(DBD_OCI_TRACEON) \
 			? PerlIO_printf(DBD_OCI_TRACEFP,\
 				 "%sOCILobLocatorIsInit_log_stat(%p,%p,%p,%d)=%s\n",\
-				 OciTp, (void*)envhp, (void*)errhp,loc,is_init,oci_status_name(stat)),stat \
+				 OciTp, (void*)envhp, (void*)errhp,loc,*is_initp,oci_status_name(stat)),stat \
 	: stat
 
 #define OCIObjectPin_log_stat(envhp,errhp,or,ot,stat)\
@@ -133,7 +172,7 @@
 	: stat
 
 #define OCIDateTimeToText_log_stat(envhp,errhp,d,sl,sb,stat)\
-	stat = OCIDateTimeToText(envhp,errhp, *(OCIDateTime**)d,(CONST text*) 0,(ub1) 0,0, (CONST text*) 0, (ub4) 0,(ub4 *)sl,sb );\
+	stat = OCIDateTimeToText(envhp,errhp, *(OCIDateTime**)d,(CONST text*) 0,(ub1) 0,6, (CONST text*) 0, (ub4) 0,(ub4 *)sl,sb );\
 	(DBD_OCI_TRACEON) \
 			?	PerlIO_printf(DBD_OCI_TRACEFP,\
 				 "%sOCIDateTimeToText(%p,%p,%p,%s)=%s\n",\
@@ -222,8 +261,8 @@
 	stat = OCINlsEnvironmentVariableGet(	valp, size, item, charset, rsizep ); \
 	(DBD_OCI_TRACEON) \
 	?	PerlIO_printf(DBD_OCI_TRACEFP,\
-		 "%sNlsEnvironmentVariableGet(%d,%d,%d,%d,%d)=%s\n",\
-		 OciTp, *valp, size, item, charset, *rsizep, oci_status_name(stat)),stat \
+		 "%sNlsEnvironmentVariableGet(%d,%lu,%d,%d,%lu)=%s\n",\
+		 OciTp, *valp, (unsigned long)size, item, charset, (unsigned long)*rsizep, oci_status_name(stat)),stat \
 	: stat
 
 /* added by lab */
@@ -231,7 +270,7 @@
 	stat = OCIEnvNlsCreate(envp, mode, ctxp, f1, f2, f3, sz, usremepp ,chset, nchset ); \
 	(DBD_OCI_TRACEON) \
 	?	PerlIO_printf(DBD_OCI_TRACEFP,\
-		 "%sNlsEnvCreate(%p,%s,%d,%d,%p,%p,%p,%d,%p,%d,%d)=%s\n", \
+		 "%sEnvNlsEnvCreate(%p,%s,%d,%d,%p,%p,%p,%d,%p,%d,%d)=%s\n", \
 		 OciTp, (void*)envp, oci_mode(mode),mode, ctxp, (void*)f1, (void*)f2, (void*)f3, sz, (void*)usremepp ,chset, nchset, oci_status_name(stat)),stat \
 	: stat
 
@@ -239,8 +278,15 @@
 #define OCIAttrGet_log_stat(th,ht,ah,sp,at,eh,stat)					\
 	stat = OCIAttrGet(th,ht,ah,sp,at,eh);				\
 	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
-		"%sAttrGet(%p,%s,%p,%p,%lu,%p)=%s\n",			\
-		OciTp, (void*)th,oci_hdtype_name(ht),(void*)ah,pul_t(sp),ul_t(at),(void*)eh,\
+		"%sAttrGet(%p,%s,%p,%p,%s,%p)=%s\n",			\
+		OciTp, (void*)th,oci_hdtype_name(ht),(void*)ah,pul_t(sp),oci_attr_name(at),(void*)eh,\
+		oci_status_name(stat)),stat : stat
+
+#define OCIAttrGet_d_log_stat(th,ht,ah,sp,at,eh,stat)					\
+	stat = OCIAttrGet(th,ht,ah,sp,at,eh);				\
+	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
+		"%sAttrGet(%p,%s,%p,%p,%s,%p)=%s\n",			\
+		OciTp, (void*)th,oci_hdtype_name(ht),(void*)ah,pul_t(sp),oci_dtype_attr_name(at),(void*)eh,\
 		oci_status_name(stat)),stat : stat
 
  #define OCIAttrGet_parmap(imp_sth,dh, ht, p1, l, stat)				\
@@ -249,7 +295,7 @@
 
 
 #define OCIAttrGet_parmdp(imp_sth, parmdp, p1, l, a, stat)				\
-	OCIAttrGet_log_stat(parmdp, OCI_DTYPE_PARAM,			\
+	OCIAttrGet_d_log_stat(parmdp, OCI_DTYPE_PARAM,			\
 		(void*)(p1), (l), (a), imp_sth->errhp, stat)
 
 #define OCIAttrGet_stmhp_stat(imp_sth, p1, l, a, stat)					\
@@ -259,8 +305,8 @@
 #define OCIAttrSet_log_stat(th,ht,ah,s1,a,eh,stat)						\
 	stat=OCIAttrSet(th,ht,ah,s1,a,eh);				\
 	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
-		"%sAttrSet(%p,%s,%p,%lu,%lu,%p)=%s\n",			\
-		OciTp, (void*)th,oci_hdtype_name(ht),(void*)(ah),ul_t(s1),ul_t(a),(void*)eh,	\
+		"%sAttrSet(%p,%s, %p,%lu,Attr=%s,%p)=%s\n",			\
+		OciTp, (void*)th,oci_hdtype_name(ht),(void *)ah,ul_t(s1),oci_attr_name(a),(void*)eh,	\
 		oci_status_name(stat)),stat : stat
 
 #define OCIBindByName_log_stat(sh,bp,eh,p1,pl,v,vs,dt,in,al,rc,mx,cu,md,stat)	\
@@ -348,13 +394,6 @@
 		"%sHandleFree(%p,%s)=%s\n",OciTp,(void*)hp,oci_hdtype_name(t),		\
 		oci_status_name(stat)),stat : stat
 
-#define OCIInitialize_log_stat(md,cp,mlf,rlf,mfp,stat)				 \
-	stat=OCIInitialize(md,cp,mlf,rlf,mfp);				\
-	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
-		"%sInitialize(with mode =%s %lu,%p,%p,%p,%p)=%s\n",				\
-		OciTp, oci_mode(md),ul_t(md),(void*)cp,(void*)mlf,(void*)rlf,(void*)mfp,	\
-		oci_status_name(stat)),stat : stat
-
 #define OCILobGetLength_log_stat(sh,eh,lh,l,stat)						\
 	stat=OCILobGetLength(sh,eh,lh,l);				\
 	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
@@ -456,9 +495,9 @@
 #define OCIParamGet_log_stat(hp,ht,eh,pp,ps,stat)						\
 	stat=OCIParamGet(hp,ht,eh,pp,ps);				\
 	(DBD_OCI_TRACEON) ? PerlIO_printf(DBD_OCI_TRACEFP,			\
-		"%sParamGet(%p,%lu,%p,%p,%lu)=%s\n",				\
+		"%sParamGet(%p,%lu,%p,%p,%lu,%s)=%s\n",				\
 		OciTp, (void*)hp,ul_t((ht)),(void*)eh,(void*)pp,ul_t(ps),	\
-		oci_status_name(stat)),stat : stat
+		oci_hdtype_name(ht),oci_status_name(stat)),stat : stat
 
 #define OCIServerAttach_log_stat(imp_dbh, dbname,md,stat)				 \
 	stat=OCIServerAttach( imp_dbh->srvhp, imp_dbh->errhp,		\
